package com.bytesw.bytebot.model;

import com.bytesw.bytebot.model.converters.AgentStatusConverter;
import com.bytesw.bytebot.model.converters.AgentTypeConverter;
import com.bytesw.bytebot.model.enums.AgentStatusEnum;
import com.bytesw.bytebot.model.enums.AgentTypeEnum;
import com.bytesw.bytebot.model.enums.LanguageEnum;
import lombok.*;

import javax.persistence.*;
import java.io.Serializable;

@Entity
@Getter @Setter @ToString @EqualsAndHashCode(of = "id")
@NoArgsConstructor
@Table(name = "BBOT_AGENT")
@NamedQuery(name = "Agent.findByPK", query = "Select u from Agent u where u.id = ?1")
public class Agent implements Serializable {

    @Id
    @TableGenerator(name = "BBOT_AGENT_GENERATOR", table = "SEQUENCE_TABLE", pkColumnName = "SEQ_NAME",
            valueColumnName = "SEQ_COUNT", pkColumnValue = "BBOT_AGENT_SEQ", allocationSize = 1)
    @GeneratedValue(strategy = GenerationType.TABLE, generator = "BBOT_AGENT_GENERATOR")
    @Column(name = "AGEN_ID")
    private Long id;

    @Column(name = "AGEN_IDEN", nullable = false)
    private String identifier;

    @Column(name = "AGEN_DESCR", nullable = false)
    private String description;

    @Column(name = "AGEN_VERS", nullable = false)
    private String version;

    @Column(name = "AGEN_LANG", nullable = false)
    @Convert(converter =  AgentTypeConverter.class)
    private LanguageEnum language;

    @Column(name = "AGEN_TZONE", nullable = false)
    private String timeZone;

    @Column(name = "AGEN_TZONE", nullable = false)
    private Country country;

    @Column(name = "AGEN_STATE", nullable = false)
    @Convert(converter =  AgentStatusConverter.class)
    private AgentStatusEnum state;

    @Column(name = "AGEN_TYPE", nullable = false)
    @Convert(converter =  AgentTypeConverter.class)
    private AgentTypeEnum type;
}
